from distutils.core import setup

setup(
        name        = 'testdemo',
        version     = '1.3.0',
        author      = 'huangqihao',
        url         = '',
        author_email= 'huangqihao8@gmail.com,',
        description = 'A simple demo of nested lists',
    )
